@@ -43,7 +43,7 @@
 #include "structures.h"
 
 #define BLOB_MATCHING_ON
-typedef void (*TESS_TESTER) (TBLOB *, BOOL8, char *, INT32, LIST);
+typedef void (*TESS_TESTER) (TBLOB *, BOOL8, char *, inT32, LIST);
 typedef LIST (*TESS_MATCHER) (TBLOB *, TBLOB *, TBLOB *, void *, TEXTROW *);
 
 extern TEXTROW normalized_row;
