@@ -44,7 +44,7 @@ const char *format, ...          //special message
   static FILE *debugfp = NULL;   //debug file
                                  //debug window
   static DEBUG_WIN *debugwin = NULL;
-  INT32 offset = 0;              //into message
+  inT32 offset = 0;              //into message
   static char msg[MAX_MSG_LEN + 1];
 
   va_start(args, format);  //variable list
