@@ -31,6 +31,7 @@
 #include "emalloc.h"
 #include "freelist.h"
 #include "callcpp.h"
+#include "tprintf.h"
 #include "adaptmatch.h"
 #include "scanutils.h"
 #include "globals.h"
@@ -122,6 +123,10 @@ int AddProtoToClass(CLASS_TYPE Class) {
   }
   NewProto = NumProtosIn (Class);
   NumProtosIn (Class)++;
+  if (NumProtosIn(Class) > MAX_NUM_PROTOS) {
+    tprintf("Ouch! number of protos = %d, vs max of %d!",
+            NumProtosIn(Class), MAX_NUM_PROTOS);
+  }
   return (NewProto);
 }
 
@@ -132,7 +137,7 @@ int AddProtoToClass(CLASS_TYPE Class) {
  * Return the length of all the protos in this class.
  **********************************************************************/
 FLOAT32 ClassConfigLength(CLASS_TYPE Class, BIT_VECTOR Config) {
-  INT16 Pid;
+  inT16 Pid;
   FLOAT32 TotalLength = 0;
 
   for (Pid = 0; Pid < NumProtosIn (Class); Pid++) {
@@ -151,7 +156,7 @@ FLOAT32 ClassConfigLength(CLASS_TYPE Class, BIT_VECTOR Config) {
  * Return the length of all the protos in this class.
  **********************************************************************/
 FLOAT32 ClassProtoLength(CLASS_TYPE Class) {
-  INT16 Pid;
+  inT16 Pid;
   FLOAT32 TotalLength = 0;
 
   for (Pid = 0; Pid < NumProtosIn (Class); Pid++) {
@@ -270,7 +275,7 @@ CLASS_TYPE NewClass(int NumProtos, int NumConfigs) {
  * Print the list of prototypes in this class type.
  **********************************************************************/
 void PrintProtos(CLASS_TYPE Class) {
-  INT16 Pid;
+  inT16 Pid;
 
   for (Pid = 0; Pid < NumProtosIn (Class); Pid++) {
     cprintf ("Proto %d:\t", Pid);
@@ -331,8 +336,8 @@ void ReadClassFromFile(FILE *File, UNICHAR_ID unichar_id) {
  * the requested number of lines.
  **********************************************************************/
 void ReadConfigs(register FILE *File, CLASS_TYPE Class) {
-  INT16 Cid;
-  register INT16 Wid;
+  inT16 Cid;
+  register inT16 Wid;
   register BIT_VECTOR ThisConfig;
   int NumWords;
   int NumConfigs;
@@ -361,7 +366,7 @@ void ReadConfigs(register FILE *File, CLASS_TYPE Class) {
  * of lines requested.
  **********************************************************************/
 void ReadProtos(register FILE *File, CLASS_TYPE Class) {
-  register INT16 Pid;
+  register inT16 Pid;
   register PROTO Proto;
   int NumProtos;
 
