@@ -82,11 +82,11 @@ static IMAGETYPE imagetypes[] = { {
  * has no extension, and complaining if the extension is not supported.
  **********************************************************************/
 
-static INT8 name_to_image_type(                  //get image type
+static inT8 name_to_image_type(                  //get image type
                                const char *name  //name of image
                               ) {
   const char *nametype;          //type part of name
-  INT8 type;                     //imagetypes index
+  inT8 type;                     //imagetypes index
 
   nametype = strrchr (name, '.');//find extension
   if (nametype != NULL)
@@ -98,7 +98,7 @@ static INT8 name_to_image_type(                  //get image type
   for (type = 0; type < MAXIMAGETYPES && strcmp (imagetypes[type].string, nametype); type++);
   if (type >= MAXIMAGETYPES) {
                                  //unrecognized type
-    BADIMAGETYPE.error ("name_to_image_type", LOG, name);
+    BADIMAGETYPE.error ("name_to_image_type", TESSLOG, name);
     return -1;
   }
   return type;
@@ -112,16 +112,16 @@ static INT8 name_to_image_type(                  //get image type
  * the name.  Return is 0 for success, -1 for failure.
  **********************************************************************/
 
-INT8 IMAGE::read_header(                  //get file header
+inT8 IMAGE::read_header(                  //get file header
                         const char *name  //name of image
                        ) {
-  INT8 type;                     //image type
+  inT8 type;                     //image type
 
   destroy();  //destroy old image
                                  //get type
   type = name_to_image_type (name);
   if (type < 0 || imagetypes[type].opener == NULL) {
-    CANTREADIMAGETYPE.error ("IMAGE::read_header", LOG, name);
+    CANTREADIMAGETYPE.error ("IMAGE::read_header", TESSLOG, name);
     return -1;                   //read not supported
   }
   #ifdef __UNIX__
@@ -131,7 +131,7 @@ INT8 IMAGE::read_header(                  //get file header
     if ((fd = open (name, O_RDONLY | O_BINARY)) < 0)
   #endif
   {
-    CANTOPENFILE.error ("IMAGE::read_header", LOG, name);
+    CANTOPENFILE.error ("IMAGE::read_header", TESSLOG, name);
     return -1;                   //failed
   }
   lineskip =
@@ -140,7 +140,7 @@ INT8 IMAGE::read_header(                  //get file header
   if (lineskip == -1) {
                                  //get header
     bpp = 0;                     //still empty
-    close(fd); 
+    close(fd);
     fd = -1;
     return -1;                   //failed
   }
@@ -171,10 +171,10 @@ INT8 IMAGE::read_header(                  //get file header
  * Read returns -1 in case of failure or 0 if successful.
  **********************************************************************/
 
-INT8 IMAGE::read(                //get rest of image
-                 INT32 buflines  //size of buffer
+inT8 IMAGE::read(                //get rest of image
+                 inT32 buflines  //size of buffer
                 ) {
-  INT32 row;                     //image row
+  inT32 row;                     //image row
   BOOL8 failed;                  //read failed
 
   if (fd < 0 || image != NULL)
@@ -184,10 +184,10 @@ INT8 IMAGE::read(                //get rest of image
     buflines = ysize;            //default to all
   bufheight = buflines;
   image =
-    (UINT8 *) alloc_big_mem ((size_t) (xdim * bufheight * sizeof (UINT8)));
+    (uinT8 *) alloc_big_mem ((size_t) (xdim * bufheight * sizeof (uinT8)));
   if (image == NULL) {
-    MEMORY_OUT.error ("IMAGE::read", LOG, NULL);
-    destroy(); 
+    MEMORY_OUT.error ("IMAGE::read", TESSLOG, NULL);
+    destroy();
     return -1;
   }
   captured = FALSE;
@@ -208,8 +208,8 @@ INT8 IMAGE::read(                //get rest of image
     }
   }
   if (failed) {
-    READFAILED.error ("IMAGE::read", LOG, NULL);
-    destroy(); 
+    READFAILED.error ("IMAGE::read", TESSLOG, NULL);
+    destroy();
     return -1;                   //read failed
   }
   if (ymin <= 0) {
@@ -226,12 +226,12 @@ INT8 IMAGE::read(                //get rest of image
  * Read a bit more of an image into the buffer.
  **********************************************************************/
 
-INT8 IMAGE::bufread(         //read more into buffer
-                    INT32 y  //required coord
+inT8 IMAGE::bufread(         //read more into buffer
+                    inT32 y  //required coord
                    ) {
-  INT32 readtop;                 //no of lines copied
-  INT32 linestoread;             //no of lines to read
-  INT32 row;                     //row to read
+  inT32 readtop;                 //no of lines copied
+  inT32 linestoread;             //no of lines to read
+  inT32 row;                     //row to read
   BOOL8 failed;                  //read failed
 
                                  //copy needed?
@@ -259,7 +259,7 @@ INT8 IMAGE::bufread(         //read more into buffer
     }
   }
   if (failed) {
-    READFAILED.error ("IMAGE::bufread", LOG, NULL);
+    READFAILED.error ("IMAGE::bufread", TESSLOG, NULL);
     return -1;                   //read failed
   }
   if (ymin <= 0) {
@@ -276,10 +276,10 @@ INT8 IMAGE::bufread(         //read more into buffer
  * Write an image to a file in a format determined by the name.
  **********************************************************************/
 
-INT8 IMAGE::write(                  //write image
+inT8 IMAGE::write(                  //write image
                   const char *name  //name to write
                  ) {
-  INT8 type;                     //type of image
+  inT8 type;                     //type of image
 
   if (bpp == 0 || image == NULL || bufheight != ysize)
     IMAGEUNDEFINED.error ("IMAGE::write", ABORT, NULL);
@@ -290,7 +290,7 @@ INT8 IMAGE::write(                  //write image
                                  //get image type
   type = name_to_image_type (name);
   if (type < 0 || imagetypes[type].writer == NULL) {
-    CANTWRITEIMAGETYPE.error ("IMAGE::write", LOG, name);
+    CANTWRITEIMAGETYPE.error ("IMAGE::write", TESSLOG, name);
     return -1;                   //write not supported
   }
   #ifdef __UNIX__
@@ -303,7 +303,7 @@ INT8 IMAGE::write(                  //write image
       if ((fd = creat (name, O_WRONLY | O_BINARY)) < 0)
   #endif
   {
-    CANTCREATEFILE.error ("IMAGE::write", LOG, name);
+    CANTCREATEFILE.error ("IMAGE::write", TESSLOG, name);
     return -1;                   //failed
   }
   if (res <= 0)
@@ -312,8 +312,8 @@ INT8 IMAGE::write(                  //write image
   res) < 0) {
                                  //get header
                                  //write failed
-    WRITEFAILED.error ("IMAGE::write", LOG, name);
-    close(fd); 
+    WRITEFAILED.error ("IMAGE::write", TESSLOG, name);
+    close(fd);
     fd = -1;
     return -1;                   //failed
   }
