@@ -28,7 +28,7 @@
 #include "efio.h"
 #include "emalloc.h"
 #include "featdefs.h"
-#include "getopt.h"
+#include "tessopt.h"
 #include "ocrfeatures.h"
 #include "general.h"
 #include "clusttool.h"
@@ -37,6 +37,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <math.h>
+#include "unichar.h"
 
 #define MAXNAMESIZE	80
 #define MAX_NUM_SAMPLES	10000
@@ -48,6 +49,7 @@ int	row_number;						/* cjn: fixes link problem */
 typedef struct
 {
   char		*Label;
+  int       SampleCount;
   LIST		List;
 }
 LABELEDLISTNODE, *LABELEDLIST;
@@ -113,7 +115,7 @@ void AddToNormProtosList(
 
 void WriteProtos(
      FILE	*File,
-     UINT16	N,
+     uinT16	N,
      LIST	ProtoList,
      BOOL8	WriteSigProtos,
      BOOL8	WriteInsigProtos);
@@ -142,7 +144,7 @@ static BOOL8		ShowInsignificantProtos = FALSE;
 //-M 0.025   -B 0.05   -I 0.8   -C 1e-3
 static CLUSTERCONFIG	Config =
 {
-  elliptical, 0.025, 0.05, 0.8, 1e-3
+  elliptical, 0.025, 0.05, 0.8, 1e-3, 0
 };
 
 static FLOAT32 RoundingAccuracy = 0.0;
@@ -219,21 +221,35 @@ int main (
 	ParseArguments (argc, argv);
 	while ((PageName = GetNextFilename()) != NULL)
 	{
-		printf ("\nReading %s ...", PageName);
+		printf ("Reading %s ...\n", PageName);
 		TrainingPage = Efopen (PageName, "r");
 		ReadTrainingSamples (TrainingPage, &CharList);
 		fclose (TrainingPage);
 		//WriteTrainingSamples (Directory, CharList);
 	}
+        printf("Clustering ...\n");
 	pCharList = CharList;
 	iterate(pCharList)
 	{
-		//Cluster
-		CharSample = (LABELEDLIST) first (pCharList);
-		printf ("\nClustering %s ...", CharSample->Label);
-		Clusterer = SetUpForClustering(CharSample);
-		ProtoList = ClusterSamples(Clusterer, &Config);
-		AddToNormProtosList(&NormProtoList, ProtoList, CharSample->Label);
+          //Cluster
+          CharSample = (LABELEDLIST) first_node (pCharList);
+          //printf ("\nClustering %s ...", CharSample->Label);
+          Clusterer = SetUpForClustering(CharSample);
+          float SavedMinSamples = Config.MinSamples;
+          Config.MagicSamples = CharSample->SampleCount;
+          while (Config.MinSamples > 0.001) {
+            ProtoList = ClusterSamples(Clusterer, &Config);
+            if (NumberOfProtos(ProtoList, 1, 0) > 0)
+              break;
+            else {
+              Config.MinSamples *= 0.95;
+              printf("0 significant protos for %s."
+                     " Retrying clustering with MinSamples = %f%%\n",
+                     CharSample->Label, Config.MinSamples);
+            }
+          }
+          Config.MinSamples = SavedMinSamples;
+          AddToNormProtosList(&NormProtoList, ProtoList, CharSample->Label);
 	}
 	FreeTrainingSamples (CharList);
 	WriteNormProtos (Directory, NormProtoList, Clusterer);
@@ -262,7 +278,7 @@ void ParseArguments(
 **		ShowSignificantProtos	flag controlling proto display
 **		ShowInsignificantProtos	flag controlling proto display
 **		Config			current clustering parameters
-**		optarg, optind		defined by getopt sys call
+**		tessoptarg, tessoptind		defined by tessopt sys call
 **		Argc, Argv		global copies of argc and argv
 **	Operation:
 **		This routine parses the command line arguments that were
@@ -287,58 +303,57 @@ void ParseArguments(
 	int		Option;
 	int		ParametersRead;
 	BOOL8		Error;
-	extern char	*optarg;
 
 	Error = FALSE;
 	Argc = argc;
 	Argv = argv;
-	while (( Option = getopt( argc, argv, "R:N:D:C:I:M:B:S:d:n:p" )) != EOF )
+	while (( Option = tessopt( argc, argv, "R:N:D:C:I:M:B:S:d:n:p" )) != EOF )
     {
 		switch ( Option )
 		{
 		case 'n':
-      sscanf(optarg,"%d", &ParametersRead);
+      sscanf(tessoptarg,"%d", &ParametersRead);
 			ShowInsignificantProtos = ParametersRead;
 			break;
 		case 'p':
-      sscanf(optarg,"%d", &ParametersRead);
+      sscanf(tessoptarg,"%d", &ParametersRead);
 			ShowSignificantProtos = ParametersRead;
 			break;
 		case 'd':
 			ShowAllSamples = FALSE;
 			break;
 		case 'C':
-			ParametersRead = sscanf( optarg, "%lf", &(Config.Confidence) );
+			ParametersRead = sscanf( tessoptarg, "%lf", &(Config.Confidence) );
 			if ( ParametersRead != 1 ) Error = TRUE;
 			else if ( Config.Confidence > 1 ) Config.Confidence = 1;
 			else if ( Config.Confidence < 0 ) Config.Confidence = 0;
 			break;
 		case 'I':
-			ParametersRead = sscanf( optarg, "%f", &(Config.Independence) );
+			ParametersRead = sscanf( tessoptarg, "%f", &(Config.Independence) );
 			if ( ParametersRead != 1 ) Error = TRUE;
 			else if ( Config.Independence > 1 ) Config.Independence = 1;
 			else if ( Config.Independence < 0 ) Config.Independence = 0;
 			break;
 		case 'M':
-			ParametersRead = sscanf( optarg, "%f", &(Config.MinSamples) );
+			ParametersRead = sscanf( tessoptarg, "%f", &(Config.MinSamples) );
 			if ( ParametersRead != 1 ) Error = TRUE;
 			else if ( Config.MinSamples > 1 ) Config.MinSamples = 1;
 			else if ( Config.MinSamples < 0 ) Config.MinSamples = 0;
 			break;
 		case 'B':
-			ParametersRead = sscanf( optarg, "%f", &(Config.MaxIllegal) );
+			ParametersRead = sscanf( tessoptarg, "%f", &(Config.MaxIllegal) );
 			if ( ParametersRead != 1 ) Error = TRUE;
 			else if ( Config.MaxIllegal > 1 ) Config.MaxIllegal = 1;
 			else if ( Config.MaxIllegal < 0 ) Config.MaxIllegal = 0;
 			break;
 		case 'R':
-			ParametersRead = sscanf( optarg, "%f", &RoundingAccuracy );
+			ParametersRead = sscanf( tessoptarg, "%f", &RoundingAccuracy );
 			if ( ParametersRead != 1 ) Error = TRUE;
 			else if ( RoundingAccuracy > 0.01 ) RoundingAccuracy = 0.01;
 			else if ( RoundingAccuracy < 0.0 ) RoundingAccuracy = 0.0;
 			break;
 		case 'S':
-			switch ( optarg[0] )
+			switch ( tessoptarg[0] )
 			{
 			case 's': Config.ProtoStyle = spherical; break;
 			case 'e': Config.ProtoStyle = elliptical; break;
@@ -348,10 +363,10 @@ void ParseArguments(
 			}
 			break;
 			case 'D':
-				Directory = optarg;
+				Directory = tessoptarg;
 				break;
 			case 'N':
-				if (sscanf (optarg, "%d", &MaxNumSamples) != 1 ||
+				if (sscanf (tessoptarg, "%d", &MaxNumSamples) != 1 ||
 					MaxNumSamples <= 0)
 					Error = TRUE;
 				break;
@@ -375,7 +390,7 @@ char *GetNextFilename ()
 /*
 **	Parameters: none
 **	Globals:
-**		optind			defined by getopt sys call
+**		tessoptind			defined by tessopt sys call
 **		Argc, Argv		global copies of argc and argv
 **	Operation:
 **		This routine returns the next command line argument.  If
@@ -388,8 +403,8 @@ char *GetNextFilename ()
 */
 
 {
-	if (optind < Argc)
-		return (Argv [optind++]);
+	if (tessoptind < Argc)
+		return (Argv [tessoptind++]);
 	else
 		return (NULL);
 
@@ -417,32 +432,33 @@ void ReadTrainingSamples (
 */
 
 {
-	char			CharName[MAXNAMESIZE];
+	char		unichar[UNICHAR_LEN + 1];
 	LABELEDLIST	CharSample;
 	FEATURE_SET	FeatureSamples;
-	CHAR_DESC		CharDesc;
-	int			Type, i;
+	CHAR_DESC	CharDesc;
+	int		Type, i;
 
-	while (fscanf (File, "%s %s", FontName, CharName) == 2) {
-		CharSample = FindList (*TrainingSamples, CharName);
-		if (CharSample == NULL) {
-			CharSample = NewLabeledList (CharName);
-			*TrainingSamples = push (*TrainingSamples, CharSample);
-		}
-		CharDesc = ReadCharDescription (File);
-		Type = ShortNameToFeatureType(PROGRAM_FEATURE_TYPE);
-		FeatureSamples = FeaturesOfType(CharDesc, Type);
-    for (int feature = 0; feature < FeatureSamples->NumFeatures; ++feature) {
-      FEATURE f = FeatureSamples->Features[feature];
-      for (int dim =0; dim < f->Type->NumParams; ++dim)
-        f->Params[dim] += UniformRandomNumber(-MINSD, MINSD);
-    }
-		CharSample->List = push (CharSample->List, FeatureSamples);
-		for (i = 0; i < NumFeatureSetsIn (CharDesc); i++)
-			if (Type != i)
-				FreeFeatureSet (FeaturesOfType (CharDesc, i));
-		free (CharDesc);
-    }
+	while (fscanf (File, "%s %s", FontName, unichar) == 2) {
+          CharSample = FindList (*TrainingSamples, unichar);
+          if (CharSample == NULL) {
+            CharSample = NewLabeledList (unichar);
+            *TrainingSamples = push (*TrainingSamples, CharSample);
+          }
+          CharDesc = ReadCharDescription (File);
+          Type = ShortNameToFeatureType(PROGRAM_FEATURE_TYPE);
+          FeatureSamples = FeaturesOfType(CharDesc, Type);
+          for (int feature = 0; feature < FeatureSamples->NumFeatures; ++feature) {
+            FEATURE f = FeatureSamples->Features[feature];
+            for (int dim =0; dim < f->Type->NumParams; ++dim)
+              f->Params[dim] += UniformRandomNumber(-MINSD, MINSD);
+          }
+          CharSample->List = push (CharSample->List, FeatureSamples);
+          CharSample->SampleCount++;
+          for (i = 0; i < NumFeatureSetsIn (CharDesc); i++)
+            if (Type != i)
+              FreeFeatureSet (FeaturesOfType (CharDesc, i));
+          free (CharDesc);
+        }
 }	// ReadTrainingSamples
 
 /*---------------------------------------------------------------------------*/
@@ -469,7 +485,7 @@ LABELEDLIST FindList (
 
 	iterate (List)
     {
-		LabeledList = (LABELEDLIST) first (List);
+		LabeledList = (LABELEDLIST) first_node (List);
 		if (strcmp (LabeledList->Label, Label) == 0)
 			return (LabeledList);
     }
@@ -500,6 +516,7 @@ LABELEDLIST NewLabeledList (
 	LabeledList->Label = (char*)Emalloc (strlen (Label)+1);
 	strcpy (LabeledList->Label, Label);
 	LabeledList->List = NIL;
+    LabeledList->SampleCount = 0;
 	return (LabeledList);
 
 }	/* NewLabeledList */
@@ -534,7 +551,7 @@ void WriteTrainingSamples (
 
 	iterate (CharList)		// iterate thru all of the fonts
 	{
-		CharSample = (LABELEDLIST) first (CharList);
+		CharSample = (LABELEDLIST) first_node (CharList);
 
 		// construct the full pathname for the current samples file
 		strcpy (Filename, "");
@@ -572,7 +589,7 @@ void WriteTrainingSamples (
 		{
 			//if (NumSamples >= MaxNumSamples) break;
 
-			FeatureSet = (FEATURE_SET) first (FeatureList);
+			FeatureSet = (FEATURE_SET) first_node (FeatureList);
 			WriteFeatureSet (File, FeatureSet);
 			NumSamples++;
 		}
@@ -606,7 +623,6 @@ void WriteNormProtos (
 	char		Filename[MAXNAMESIZE];
 	LABELEDLIST LabeledProto;
 	int N;
-	char Label;
 
 	strcpy (Filename, "");
 	if (Directory != NULL)
@@ -621,11 +637,19 @@ void WriteNormProtos (
 	WriteParamDesc(File,Clusterer->SampleSize,Clusterer->ParamDesc);
 	iterate(LabeledProtoList)
 	{
-		LabeledProto = (LABELEDLIST) first (LabeledProtoList);
+		LabeledProto = (LABELEDLIST) first_node (LabeledProtoList);
 		N = NumberOfProtos(LabeledProto->List,
-			ShowSignificantProtos, ShowInsignificantProtos);
-		Label = NameToChar(LabeledProto->Label);
-		fprintf(File, "\n%c %d\n", Label, N);
+		ShowSignificantProtos, ShowInsignificantProtos);
+                if (N < 1) {
+                  printf ("\nError! Not enough protos for %s: %d protos"
+                          " (%d significant protos"
+                          ", %d insignificant protos)\n",
+                          LabeledProto->Label, N,
+                          NumberOfProtos(LabeledProto->List, 1, 0),
+                          NumberOfProtos(LabeledProto->List, 0, 1));
+                  exit(1);
+                }
+		fprintf(File, "\n%s %d\n", LabeledProto->Label, N);
 		WriteProtos(File, Clusterer->SampleSize, LabeledProto->List,
 			ShowSignificantProtos, ShowInsignificantProtos);
 	}
@@ -658,11 +682,11 @@ void FreeTrainingSamples (
 	printf ("\nFreeTrainingSamples...");
 	iterate (CharList) 		/* iterate thru all of the fonts */
 	{
-		CharSample = (LABELEDLIST) first (CharList);
+		CharSample = (LABELEDLIST) first_node (CharList);
 		FeatureList = CharSample->List;
 		iterate (FeatureList)	/* iterate thru all of the classes */
 		{
-			FeatureSet = (FEATURE_SET) first (FeatureList);
+			FeatureSet = (FEATURE_SET) first_node (FeatureList);
 			FreeFeatureSet (FeatureSet);
 		}
 		FreeLabeledList (CharSample);
@@ -680,7 +704,7 @@ void FreeNormProtoList (
 
 	iterate (CharList) 		/* iterate thru all of the fonts */
 	{
-		CharSample = (LABELEDLIST) first (CharList);
+		CharSample = (LABELEDLIST) first_node (CharList);
 		FreeLabeledList (CharSample);
 	}
 	destroy (CharList);
@@ -734,11 +758,11 @@ CLUSTERER *SetUpForClustering(
 */
 
 {
-	UINT16	N;
+	uinT16	N;
 	int		i, j;
 	FLOAT32	*Sample = NULL;
 	CLUSTERER	*Clusterer;
-	INT32		CharID;
+	inT32		CharID;
 	LIST FeatureList = NULL;
 	FEATURE_SET FeatureSet = NULL;
 	FEATURE_DESC FeatureDesc = NULL;
@@ -754,7 +778,7 @@ CLUSTERER *SetUpForClustering(
 	CharID = 0;
 	iterate(FeatureList)
 	{
-		FeatureSet = (FEATURE_SET) first (FeatureList);
+		FeatureSet = (FEATURE_SET) first_node (FeatureList);
 		for (i=0; i < FeatureSet->MaxNumFeatures; i++)
 		{
 			if (Sample == NULL)
@@ -785,7 +809,7 @@ void AddToNormProtosList(
 	LabeledProtoList = NewLabeledList(CharName);
 	iterate(ProtoList)
 	{
-		Proto = (PROTOTYPE *) first (ProtoList);
+		Proto = (PROTOTYPE *) first_node (ProtoList);
 		LabeledProtoList->List = push(LabeledProtoList->List, Proto);
 	}
 	*NormProtoList = push(*NormProtoList, LabeledProtoList);
@@ -794,7 +818,7 @@ void AddToNormProtosList(
 /*-------------------------------------------------------------------------*/
 void WriteProtos(
      FILE	*File,
-     UINT16	N,
+     uinT16	N,
      LIST	ProtoList,
      BOOL8	WriteSigProtos,
      BOOL8	WriteInsigProtos)
@@ -804,7 +828,7 @@ void WriteProtos(
 	// write prototypes
 	iterate(ProtoList)
 	{
-		Proto = (PROTOTYPE *) first ( ProtoList );
+		Proto = (PROTOTYPE *) first_node ( ProtoList );
 		if (( Proto->Significant && WriteSigProtos )	||
 			( ! Proto->Significant && WriteInsigProtos ) )
 			WritePrototype( File, N, Proto );
@@ -822,11 +846,10 @@ int NumberOfProtos(
 
 	iterate(ProtoList)
 	{
-		Proto = (PROTOTYPE *) first ( ProtoList );
+		Proto = (PROTOTYPE *) first_node ( ProtoList );
 		if (( Proto->Significant && CountSigProtos )	||
 			( ! Proto->Significant && CountInsigProtos ) )
 			N++;
 	}
 	return(N);
 }
-
